local addonName, addon = ...
local addonCommand = GetAddOnMetadata(addonName, "X-SlashCommand")
local addonOptions

local f = CreateFrame("Frame")
f:SetScript("OnEvent", function(self, event, ...)
	self[event](self, ...)
end)

f.Maps = {
	AV  = {
		name = C_Map.GetMapInfo(1459).name,
		token = 20560
	},
	WSG = {
		name = C_Map.GetMapInfo(1460).name,
		token = 20558
	},
	AB  = {
		name = C_Map.GetMapInfo(1461).name,
		token = 20559
	}
}

local DebugPrint = function(msg)
	if addonOptions.Debug then
		_G.DEFAULT_CHAT_FRAME:AddMessage("|cffffd000" .. addonName .. ":|r " .. msg)
	end
end

local strsplit, strfind = strsplit, strfind
local GetBattlefieldStatus, IsShiftKeyDown, UnitGUID = GetBattlefieldStatus, IsShiftKeyDown, UnitGUID
local GetContainerNumSlots, GetContainerItemInfo = GetContainerNumSlots, GetContainerItemInfo

function f:UPDATE_BATTLEFIELD_STATUS(index)
	local status, bgName, bgId = GetBattlefieldStatus(index)

	if status == "confirm" and bgName == self.Maps.AV.name then
		local chatType
		if IsInRaid(1) then
			chatType = "RAID"
		elseif IsInGroup(1) then
			chatType = "PARTY"
		end
		if chatType then
			SendChatMessage(bgId,chatType)
		end
	end
end

local IsHonorTokenNPC = function()
	local npcType,_,_,_,_,npcId = strsplit("-",UnitGUID("npc"))
	if npcType == "Creature" and (npcId == "15351" or npcId == "15350") then
		return true
	end
end

local SelectGossipQuestByTitle = function(title)
	local questInfo = { GetGossipAvailableQuests() }
	for i=1, #questInfo, 7 do
		if strfind(questInfo[i],title,1,true) then
			SelectGossipAvailableQuest(ceil(i / 7))
			break
		end
	end
end

local CountContainerItem = function(id)
	local count = 0
	for bagId = 0,4 do
		for slot = 1, GetContainerNumSlots(bagId) do
			local _,itemCount,_, _, _, _, _, _, _,itemId = GetContainerItemInfo(bagId, slot)
			if itemId and itemId == id then
				count = count + itemCount
			end
		end
	end
	return count
end

function f:GOSSIP_SHOW()
	if IsShiftKeyDown() then
		return
	end

	local availableQuests = GetNumGossipAvailableQuests()
	if availableQuests == 0 and GetNumGossipOptions() == 1 and GetNumGossipActiveQuests() == 0 then
		local _,gossipType = GetGossipOptions()
		if gossipType == "battlemaster" then
			SelectGossipOption(1)
		end
	elseif availableQuests > 0 and IsHonorTokenNPC() then
		for k in pairs(self.Maps) do
			if CountContainerItem(self.Maps[k].token) >= 3 then
				SelectGossipQuestByTitle(self.Maps[k].name)
				break
			end
		end
	end
end

function f:QUEST_PROGRESS()
	if IsShiftKeyDown() or not IsHonorTokenNPC() then
		return
	end
	local title = GetTitleText()
	for k in pairs(self.Maps) do
		if strfind(title,self.Maps[k].name,1,true) and CountContainerItem(self.Maps[k].token) >= 3 then
			CompleteQuest()
			break
		end
	end
end

function f:QUEST_COMPLETE()
	if IsShiftKeyDown() or not IsHonorTokenNPC() then
		return
	end
	if GetNumQuestRewards() == 0 then
		GetQuestReward()
	end
end

do
	local IsPVPMap = _G.C_PvP.IsPVPMap
	local GetSelfResurrectOptions = _G.C_DeathInfo.GetSelfResurrectOptions
	function f.PLAYER_DEAD()
		if IsPVPMap() and #GetSelfResurrectOptions() == 0 then
			RepopMe()
		end
	end
end

--[[
f:RegisterEvent("BATTLEFIELDS_SHOW")
function f:BATTLEFIELDS_SHOW(isArena, battleMasterListID)
	-- battleMasterListID 1=AV, 2=WSG
end
]]

local optionsPanel = addon.createOptionsPanel()
_G.InterfaceOptions_AddCategory(optionsPanel)

local buttonAnnounce = addon.createOptionsButton(optionsPanel, "Announce Battleground to Chat", "Automatically say your battleground number in chat when in a party or raid.")
local buttonMarks = addon.createOptionsButton(optionsPanel, "Automatic Mark of Honor Handling", "Automatically select and hand in quests for |cff1eff00Mark of Honor|r when speaking to the NPC.")
local buttonSpirit = addon.createOptionsButton(optionsPanel, "Instant Spirit Release", "Instantly release spirit when killed in a battleground.")

buttonAnnounce:SetPoint("TOPLEFT", 14, -80)
buttonMarks:SetPoint("TOPLEFT", buttonAnnounce, "BOTTOMLEFT", 0, -8)
buttonSpirit:SetPoint("TOPLEFT", buttonMarks, "BOTTOMLEFT", 0, -8)

--[[
local buttonSpiritAV  = addon.createOptionsButton(optionsPanel, f.Maps.AV.name, nil, true)
local buttonSpiritWSG = addon.createOptionsButton(optionsPanel, f.Maps.WSG.name, nil, true)
local buttonSpiritAB  = addon.createOptionsButton(optionsPanel, f.Maps.AB.name, nil, true)
buttonSpiritAV:SetPoint("TOPLEFT", buttonSpirit, "BOTTOMLEFT", 10, 4)
buttonSpiritWSG:SetPoint("TOPLEFT", buttonSpiritAV, "BOTTOMLEFT", 0, 4)
buttonSpiritAB:SetPoint("TOPLEFT", buttonSpiritWSG, "BOTTOMLEFT", 0, 4)
]]

buttonAnnounce.OnClick = function(self, isChecked)
	if isChecked then
		addonOptions.Announce = true
		f:RegisterEvent("UPDATE_BATTLEFIELD_STATUS")
		--_G.PlaySound(1121)
	else
		addonOptions.Announce = nil
		f:UnregisterEvent("UPDATE_BATTLEFIELD_STATUS")
	end
end
buttonMarks.OnClick = function(self, isChecked)
	if isChecked then
		addonOptions.Marks = true
		f:RegisterEvent("GOSSIP_SHOW")
		f:RegisterEvent("QUEST_PROGRESS")
		f:RegisterEvent("QUEST_COMPLETE")
	else
		addonOptions.Marks = nil
		f:UnregisterEvent("GOSSIP_SHOW")
		f:UnregisterEvent("QUEST_PROGRESS")
		f:UnregisterEvent("QUEST_COMPLETE")
	end
end
buttonSpirit.OnClick = function(self, isChecked)
	if isChecked then
		addonOptions.Release = true
		f:RegisterEvent("PLAYER_DEAD")
	else
		addonOptions.Release = nil
		f:UnregisterEvent("PLAYER_DEAD")
	end
end

f:RegisterEvent("ADDON_LOADED")
function f:ADDON_LOADED(name)
	if name == addonName then
		self:UnregisterEvent("ADDON_LOADED")
		addonOptions = _G[addonName]
		if not addonOptions then
			addonOptions = { Marks = true }
			_G[addonName] = addonOptions
		end
		if addonOptions.Announce then buttonAnnounce:Click() end
		if addonOptions.Marks then buttonMarks:Click() end
		if addonOptions.Release then buttonSpirit:Click() end
	end
end

if addonCommand then
	_G["SLASH_" .. strupper(addonCommand) .. "1"] = "/" .. strlower(addonCommand)
	_G.SlashCmdList[strupper(addonCommand)] = function(msg)
		if msg == "debug" then
			if not addonOptions.Debug then
				addonOptions.Debug = true
				DebugPrint("Debug messages turned ON")
			else
				DebugPrint("Debug messages turned OFF")
				addonOptions.Debug = nil
			end
		elseif optionsPanel then
			if not _G.InterfaceOptionsFrame:IsShown() then
				_G.InterfaceOptionsFrame:Show()
			end
			_G.InterfaceOptionsFrame_OpenToCategory(optionsPanel)
		end
	end
end
